==> banshee-0.9.12.tar.gz: banshee-0.9.12/src/Banshee.Widgets/ToggleState.cs <==
/* -*- Mode: csharp; tab-width: 4; c-basic-offset: 4; indent-tabs-mode: t -*- */
/***************************************************************************
 *  ToggleState.cs
 *
 *  Copyright (C) 2005 Novell
 *  Written by Aaron Bockover (aaron@aaronbock.net)
 ****************************************************************************/

/*  THIS FILE IS LICENSED UNDER THE MIT LICENSE AS OUTLINED IMMEDIATELY BELOW: 
 *
 *  Permission is hereby granted, free of charge, to any person obtaining a
 *  copy of this software and associated documentation files (the "Software"),  
 *  to deal in the Software without restriction, including without limitation  
 *  the rights to use, copy, modify, merge, publish, distribute, sublicense,  
 *  and/or sell copies of the Software, and to permit persons to whom the  
 *  Software is furnished to do so, subject to the following conditions:
 *
 *  The above copyright notice and this permission notice shall be included in 
 *  all copies or substantial portions of the Software.
 *
 *  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR 
 *  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, 
 *  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE 
 *  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
 *  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
 *  FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER 
 *  DEALINGS IN THE SOFTWARE.
 */

using System;
using Gtk;

namespace Banshee.Widgets 
{
    abstract public class ToggleState
    {
        private Gdk.Pixbuf icon;
        private string label;
        private CheckMenuItem menu_item;
        private bool check_active;
        
        protected ToggleState()
        {
        }
        
        internal CheckMenuItem MenuItem {
            get {
                return menu_item;
            }
            
            set {
                menu_item = value;
            }
        }
        
        internal bool CheckActive {
            get {
                return check_active;
            }
            
            set {
                check_active = value;
            }
        }
      
        public Gdk.Pixbuf Icon {
            get {
                return icon;
            }
            
            protected set {
                icon = value;
            }
        }
        
        public string Label {
            get {
                return label;
            }
            
            protected set {
                label = value;
            }
        }
    }
}

==> banshee-0.10.2.tar.gz: banshee-0.10.2/src/Banshee.Widgets/ToggleState.cs <==
/* -*- Mode: csharp; tab-width: 4; c-basic-offset: 4; indent-tabs-mode: t -*- */
/***************************************************************************
 *  ToggleState.cs
 *
 *  Copyright (C) 2005 Novell
 *  Written by Aaron Bockover (aaron@aaronbock.net)
 ****************************************************************************/

/*  THIS FILE IS LICENSED UNDER THE MIT LICENSE AS OUTLINED IMMEDIATELY BELOW: 
 *
 *  Permission is hereby granted, free of charge, to any person obtaining a
 *  copy of this software and associated documentation files (the "Software"),  
 *  to deal in the Software without restriction, including without limitation  
 *  the rights to use, copy, modify, merge, publish, distribute, sublicense,  
 *  and/or sell copies of the Software, and to permit persons to whom the  
 *  Software is furnished to do so, subject to the following conditions:
 *
 *  The above copyright notice and this permission notice shall be included in 
 *  all copies or substantial portions of the Software.
 *
 *  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR 
 *  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, 
 *  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE 
 *  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
 *  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING 
 *  FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER 
 *  DEALINGS IN THE SOFTWARE.
 */

using System;
using Gtk;

namespace Banshee.Widgets 
{
    abstract public class ToggleState
    {
        private Gdk.Pixbuf icon;
        private string label;
        private ToggleAction toggle_action;
        private bool check_active;
        
        protected ToggleState()
        {
        }
        
        internal ToggleAction ToggleAction {
            get {
                return toggle_action;
            }
            
            set {
                toggle_action = value;
            }
        }
        
        internal bool CheckActive {
            get {
                return check_active;
            }
            
            set {
                check_active = value;
            }
        }
      
        public Gdk.Pixbuf Icon {
            get {
                return icon;
            }
            
            protected set {
                icon = value;
            }
        }
        
        public string Label {
            get {
                return label;
            }
            
            protected set {
                label = value;
            }
        }
    }
}
